@@ -1,16 +1,27 @@
-/* --< GKrellStock 0.4 >--{ 8 May 2002 }--
+/* --< GKrellStock 0.5.1 >--{ 21 April 2003 }--
  *
+ * GkrellM2.0 Port
  * Author: M.R.Muthu Kumar (m_muthukumar@users.sourceforge.net)
  *
  */
 
-#include <gkrellm/gkrellm.h>
+#include <gkrellm2/gkrellm.h>
 
-#define GKRELLSTOCK_VER 	"0.4"
+/*
+ * Make sure we have a compatible version of GKrellM
+ * (Version 2.0+ is required)
+ */
+#if !defined(GKRELLM_VERSION_MAJOR) \
+     || (GKRELLM_VERSION_MAJOR < 2 )
+#error This plugin requires GKrellM version >= 2.0
+#endif
+
+
+#define GKRELLSTOCK_VER 	"0.5.1"
 #define DEFAULT_TICKERS		"T SPTN GE" 
 #define DEFAULT_S_TICKERS	"^dji ^ixic" 
 
-#define COMMAND			"GetQuote"
+#define COMMAND			"GetQuote2"
 #define DELIM			"!"
 
 #define	CONFIG_NAME	"GkrellStock"	/* Name in the configuration window */
@@ -35,9 +46,9 @@
 /*    net update status    */
 static gboolean    net_update;
 
-static Panel	*panel, *q_panel;
+static GkrellmPanel	*stk_panel, *q_panel;
 
-static Decal	*decal_text1[MAX_DECALS], *decal_text2[MAX_DECALS];
+static GkrellmDecal	*decal_text1[MAX_DECALS], *decal_text2[MAX_DECALS];
 
 static gchar	scroll_text[MAX_TICKERS][512];
 static gchar	quote_text[MAX_TICKERS][512];
@@ -55,7 +66,7 @@ static gint update_interval;
 static gint stock_src;
 static gint tic_number;
 
-static Monitor *monitor;
+static GkrellmMonitor *stk_monitor;
 
 static GtkWidget	*switch_interval_option, 
                     *update_interval_option,
@@ -68,7 +79,7 @@ static GtkTooltips  *stock_tips = 0;
 static gchar        *stock_tips_text;
 static gint	switch_timer = 0;
 
-gchar filename[512];
+gchar stk_filename[512];
 gchar *stock_src_name[] = { "usa", "europe", "australia", "canada", "asia" };
 gchar *market_name[] = { USA_M, EURO_M, AUS_M, CAN_M, ASIA_M };
 
@@ -89,11 +100,11 @@ static gboolean config_data_modified=FALSE;
 static gint
 expose_event (GtkWidget *widget, GdkEventExpose *ev)
 {
-    if (widget == panel->drawing_area)
+    if (widget == stk_panel->drawing_area)
     {
         gdk_draw_pixmap(widget->window,
             widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-            panel->pixmap, ev->area.x, ev->area.y, ev->area.x, ev->area.y,
+            stk_panel->pixmap, ev->area.x, ev->area.y, ev->area.x, ev->area.y,
             ev->area.width, ev->area.height);
     }
     if (widget == q_panel->drawing_area)
@@ -155,7 +166,7 @@ show_stock_tips()
 		    );
 
       stock_tips_text = g_strdup(str);
-      gtk_tooltips_set_tip(stock_tips, panel->drawing_area,
+      gtk_tooltips_set_tip(stock_tips, stk_panel->drawing_area,
                            stock_tips_text, NULL);
       gtk_tooltips_set_tip(stock_tips, q_panel->drawing_area,
                            stock_tips_text, NULL);
@@ -174,7 +185,7 @@ read_stock()
 
   gchar *token, *q_token;
 
-  if ( ( fp = fopen( filename, "r" ) ) != NULL )
+  if ( ( fp = fopen( stk_filename, "r" ) ) != NULL )
   {
     while ( feof( fp ) == 0  )
     {
@@ -240,14 +251,14 @@ draw_panel ()
      decal_text2[i_new]->x_off = w - x_scroll;
      gkrellm_draw_decal_text(q_panel, decal_text2[i_new], quote_text[i], w - x_scroll);
      decal_text1[i_new]->x_off = ( w / 2 ) - (strlen(scroll_text[i]) * 4);
-     gkrellm_draw_decal_text(panel, decal_text1[i_new], scroll_text[i], v);
+     gkrellm_draw_decal_text(stk_panel, decal_text1[i_new], scroll_text[i], v);
    }
    else
    {
      x_scroll = 0;
      if (w == 0) { w = gkrellm_chart_width(); }
      decal_text1[i_new]->x_off = ( w / 2 ) - (strlen(scroll_text[i]) * 4);
-     gkrellm_draw_decal_text(panel, decal_text1[i_new], scroll_text[i], v);
+     gkrellm_draw_decal_text(stk_panel, decal_text1[i_new], scroll_text[i], v);
      decal_text2[i_new]->x_off = 0;
      gkrellm_draw_decal_text(q_panel, decal_text2[i_new], quote_text[i], v);
    }
@@ -271,13 +282,13 @@ panel_switch()
    if ( panel_state > 1 ) { i_new = panel_state % 2; }
    else { i_new = panel_state; }
 
-   gkrellm_make_decal_invisible(panel, decal_text1[i_old] );
+   gkrellm_make_decal_invisible(stk_panel, decal_text1[i_old] );
    gkrellm_make_decal_invisible(q_panel, decal_text2[i_old] );
 
    draw_panel();
 
-   gkrellm_make_decal_visible(panel, decal_text1[i_new] );
-   gkrellm_draw_layers(panel);
+   gkrellm_make_decal_visible(stk_panel, decal_text1[i_new] );
+   gkrellm_draw_panel_layers(stk_panel);
    gkrellm_make_decal_visible(q_panel, decal_text2[i_new] );
 
 
@@ -296,7 +307,7 @@ panel_press (GtkWidget *widget, GdkEventButton *ev)
     }
     if (ev->button == 3 )
     {
-	  gkrellm_open_config_window (monitor);
+	  gkrellm_open_config_window (stk_monitor);
 	}
 
     return TRUE;
@@ -332,9 +343,9 @@ update_plugin()
         }
 
     draw_panel();
-	gkrellm_draw_layers(panel);
+	gkrellm_draw_panel_layers(stk_panel);
 
-	gkrellm_draw_layers(q_panel);
+	gkrellm_draw_panel_layers(q_panel);
 
 }
 
@@ -343,21 +354,21 @@ update_plugin()
 static void
 create_plugin(GtkWidget *vbox, gint first_create)
 {
-	Style			*style;
-	TextStyle		*ts, *ts_alt;
+	GkrellmStyle			*style;
+	GkrellmTextstyle		*ts, *ts_alt;
 	gint			i = 0;
 	gint			j = 0;
 	gint			prev_state = 0;
 
 	if (first_create)
 	{
-	  panel = gkrellm_panel_new0();
+	  stk_panel = gkrellm_panel_new0();
 	  q_panel = gkrellm_panel_new0();
 	}  
 	else 
 	{ 
-	  gkrellm_destroy_krell_list(panel);
-	  gkrellm_destroy_decal_list(panel); 
+	  gkrellm_destroy_krell_list(stk_panel);
+	  gkrellm_destroy_decal_list(stk_panel); 
 
 	  gkrellm_destroy_krell_list(q_panel);
 	  gkrellm_destroy_decal_list(q_panel); 
@@ -373,7 +384,7 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	*/
 	ts = gkrellm_meter_textstyle(style_id);
 	ts_alt = gkrellm_meter_alt_textstyle(style_id);
-	panel->textstyle = ts;		/* would be used for a panel label */
+	stk_panel->textstyle = ts;		/* would be used for a panel label */
 	q_panel->textstyle = ts;		/* would be used for a panel label */
 
 	/* Create a text decal that will be used to scroll text.  Make it
@@ -383,7 +394,7 @@ create_plugin(GtkWidget *vbox, gint first_create)
 
     for ( i = 0; i < MAX_DECALS ; i++ )
     {
-	   decal_text1[i] = gkrellm_create_decal_text(panel, "Ay", ts, style, -1, -1, -1);
+	   decal_text1[i] = gkrellm_create_decal_text(stk_panel, "Ay", ts, style, -1, -1, -1);
 	   decal_text2[i] = gkrellm_create_decal_text(q_panel, "Ay", ts_alt, style, -1, -1, -1);
 	 }
 
@@ -398,15 +409,14 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	/* Configure the panel to hold the above created decals, add in a little
 	|  bottom margin for looks, and create the panel.
 	*/
-        gkrellm_configure_panel(panel, NULL, style);
-        gkrellm_create_panel(vbox, panel, gkrellm_bg_meter_image(style_id));
-        gkrellm_monitor_height_adjust(panel->h);
+        gkrellm_panel_configure(stk_panel, NULL, style);
+        // gkrellm_panel_create(vbox, stk_panel, gkrellm_bg_meter_piximage(style_id));
+        gkrellm_panel_create(vbox, stk_monitor, stk_panel );
 
-        gkrellm_configure_panel(q_panel, NULL, style);
-        gkrellm_create_panel(vbox, q_panel, gkrellm_bg_meter_image(style_id));
-        gkrellm_monitor_height_adjust(q_panel->h);
+        gkrellm_panel_configure(q_panel, NULL, style);
+        gkrellm_panel_create(vbox, stk_monitor, q_panel );
 	/* Note: all of the above gkrellm_draw_decal_XXX() calls will not
-	|  appear on the panel until a 	gkrellm_draw_layers(panel); call is
+	|  appear on the panel until a 	gkrellm_draw_panel_layers(panel); call is
 	|  made.  This will be done in update_plugin(), otherwise we would
 	|  make the call here and anytime the decals are changed.
 	*/
@@ -416,7 +426,7 @@ create_plugin(GtkWidget *vbox, gint first_create)
         {
           stock_tips = gtk_tooltips_new();
           stock_tips_text = g_strdup("GKrellStock");
-          gtk_tooltips_set_tip(stock_tips, panel->drawing_area,
+          gtk_tooltips_set_tip(stock_tips, stk_panel->drawing_area,
                                stock_tips_text, NULL);
           gtk_tooltips_set_tip(stock_tips, q_panel->drawing_area,
                                stock_tips_text, NULL);
@@ -432,8 +442,8 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	      if ( i == 0 ) { prev_state = i; }
 	      else { prev_state = i - 1; }
 
-          gkrellm_make_decal_invisible(panel, decal_text1[panel_state] );
-          gkrellm_make_decal_visible(panel, decal_text1[prev_state] );
+          gkrellm_make_decal_invisible(stk_panel, decal_text1[panel_state] );
+          gkrellm_make_decal_visible(stk_panel, decal_text1[prev_state] );
 
           gkrellm_make_decal_invisible(q_panel, decal_text2[panel_state] );
           gkrellm_make_decal_visible(q_panel, decal_text2[prev_state] );
@@ -442,11 +452,11 @@ create_plugin(GtkWidget *vbox, gint first_create)
 
 	if (first_create)
 	{	
-	    gtk_signal_connect(GTK_OBJECT (panel->drawing_area), "expose_event",
+	    gtk_signal_connect(GTK_OBJECT (stk_panel->drawing_area), "expose_event",
     	        (GtkSignalFunc) expose_event, NULL);
 	    gtk_signal_connect(GTK_OBJECT (q_panel->drawing_area), "expose_event",
     	        (GtkSignalFunc) expose_event, NULL);
-	    gtk_signal_connect(GTK_OBJECT(panel->drawing_area),
+	    gtk_signal_connect(GTK_OBJECT(stk_panel->drawing_area),
             "button_press_event", (GtkSignalFunc) panel_press, NULL);
 	    gtk_signal_connect(GTK_OBJECT(q_panel->drawing_area),
             "button_press_event", (GtkSignalFunc) panel_press, NULL);
@@ -654,7 +664,7 @@ apply_stock_config (void)
     switch_interval = gtk_spin_button_get_value_as_int(
             GTK_SPIN_BUTTON(switch_interval_option));
 
-    c = gkrellm_entry_get_text(&(GTK_COMBO(market_select_option)->entry));
+    c = gkrellm_gtk_entry_get_text(&(GTK_COMBO(market_select_option)->entry));
     stock_src = stock_src_set( c );
     sprintf( command, "%s %s %s", COMMAND, stock_src_name[stock_src], tickers );
     run_command();
@@ -673,7 +683,7 @@ static void cbUpdate (GtkWidget *widget, gpointer data)
 
   tmp_buf[0] = (gtk_toggle_button_get_active
                (GTK_TOGGLE_BUTTON (scroll_option)) == TRUE ? "Yes" : "No");
-  tmp_buf[1] = gkrellm_entry_get_text (&ticker_option);
+  tmp_buf[1] = gkrellm_gtk_entry_get_text (&ticker_option);
 
   /*
    * Ignore empty tickers.
@@ -1003,10 +1013,10 @@ create_stock_tab (GtkWidget *tab)
     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(frame), info_window);
 
-    text = gtk_text_new(NULL, NULL);
+    text = gtk_text_view_new();
 
-    gkrellm_add_info_text(text, help_text, sizeof(help_text)/sizeof(gchar*));
-    gtk_text_set_editable(GTK_TEXT(text), FALSE);
+	gkrellm_gtk_text_view_append_strings(text, help_text, sizeof(help_text)/sizeof(gchar*));
+    gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
     gtk_container_add(GTK_CONTAINER(info_window), text);
 
     label = gtk_label_new("Help");
@@ -1017,7 +1027,7 @@ create_stock_tab (GtkWidget *tab)
         "GKrellStock %s\n" \
         "GKrellM Stock Plugin\n" \
         "\n" \
-        "Copyright (C) 2002 M.R.Muthu Kumar\n" \
+        "Copyright (C) 2003 M.R.Muthu Kumar\n" \
         "m_muthukumar@users.sourceforge.net\n" \
         "\n" \
         "Released under the GNU Public License\n" \
@@ -1037,7 +1047,7 @@ create_stock_tab (GtkWidget *tab)
 
 /* The monitor structure tells GKrellM how to call the plugin routines.
 */
-static Monitor	plugin_mon	=
+static GkrellmMonitor	plugin_mon	=
 	{
 	CONFIG_NAME,        	/* Name, for config tab.    */
 	0,			/* Id,  0 if a plugin       */
@@ -1080,15 +1090,15 @@ read_default(void)
 
    set_tickers();
 
-   sprintf( filename, "%s/.smStockReports/stockinfo.dat", getenv( "HOME" ) );
+   sprintf( stk_filename, "%s/.smStockReports2/stockinfo.dat", getenv( "HOME" ) );
    sprintf( command, "%s %s %s", COMMAND, stock_src_name[stock_src], tickers );
 }	
 
   /* All GKrellM plugins must have one global routine named init_plugin()
   |  which returns a pointer to a filled in monitor structure.
   */
-Monitor *
-init_plugin()
+GkrellmMonitor *
+gkrellm_init_plugin()
 	{
 	/* If this call is made, the background and krell images for this plugin
 	|  can be custom themed by putting bg_meter.png or krell.png in the
@@ -1111,5 +1121,5 @@ init_plugin()
 
 	net_update = FALSE;
 
-	return (monitor = &plugin_mon);
+	return (stk_monitor = &plugin_mon);
 	}
